@@ -539,7 +539,7 @@ class LocalPorvider(BaseProvider):
             output: DataFrame
             fields : ...
         """
-        return FRP.repo_issuedate_pre(instruments,fields,**kws)
+        return FRP.repo_fanc_indicator(instruments,fields,**kws)
     
     def frepo_qdii_secuportfolio(self,instruments,fields = None,**kws):
         """
@@ -607,6 +607,17 @@ class LocalPorvider(BaseProvider):
         """
         return CDP.suntime_confc_stk(instruments,fields,**kws)
 
+    def suntime_confc_roll_stk(self,instruments,fields = None,**kws):
+        """
+            table_name: 'CON_FORECAST_STK'
+            input:instruments:List(str),fields:List(str)
+                  window_days: 30d,90d,180d
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return CDP.suntime_confc_roll_stk(instruments,fields,**kws)
+
     def suntime_repofc_stk(self,instruments,fields = None,**kws):
         """
             table_name: 'RPT_FORECAST_STK'
