@@ -38,6 +38,7 @@ ashare_sktrating_90d = os.path.join(data_path,r"AShareStockRatingConsus_90D")
 ashare_sktrating_180d = os.path.join(data_path,r"AShareStockRatingConsus_180D")
 
 suntime_confc_stk = os.path.join(data_path,r"CON_FORECAST_STK")
+suntime_confc_roll_stk = os.path.join(data_path,r"CON_FORECAST_ROLL_STK")
 suntime_repofc_stk = os.path.join(data_path,r"RPT_FORECAST_STK")
 
 class BaseConsusDataProvider(abc.ABC):
@@ -93,6 +94,10 @@ class LoacalConsusProvider(BaseConsusDataProvider):
     def suntime_confc_stk(self,instruments,fields,**kws):
         return self.get_repo_data(suntime_confc_stk,instruments,fields,tidx = ["con_date"],**kws)
 
+    @print_func_time
+    def suntime_confc_roll_stk(self,instruments,fields,**kws):
+        return self.get_repo_data(suntime_confc_roll_stk,instruments,fields,tidx = ["con_date"],**kws)
+
     @print_func_time
     def suntime_repofc_stk(self,instruments,fields,**kws):
         return self.get_repo_data(suntime_repofc_stk,instruments,fields,tidx = ["create_date"],**kws)
\ No newline at end of file
