@@ -17,6 +17,8 @@ ashare_profit_expr = os.path.join(data_path,r'AShareProfitExpress')
 ashare_profit_noti = os.path.join(data_path,r'AShareProfitNotice')
 ashare_ttmhis = os.path.join(data_path,r'AShareTTMHis')
 ashare_holdernumber = os.path.join(data_path,r'AShareHolderNumber')
+ashare_insideholder =  os.path.join(data_path,r'AShareInsideHolder')
+
 ashare_issuedate_pre = os.path.join(data_path,r'AShareIssuingDatePredict')
 ashare_fanc_indicator = os.path.join(data_path,r'AShareFinancialIndicator')
 
@@ -92,7 +94,11 @@ class LoacalFincReportsProvider(BaseFincReportsProvider):
     @print_func_time
     def repo_holder_number(self,instruments,fields,**kws):
         return self.get_repo_data(ashare_holdernumber,instruments,fields,tidx = ["ann_date"],**kws) 
-    
+
+    @print_func_time
+    def repo_inside_holder(self,instruments,fields,**kws):
+        return self.get_repo_data(ashare_insideholder,instruments,fields,tidx = ["ann_date"],**kws) 
+
     @print_func_time
     def repo_issuedate_pre(self,instruments,fields,**kws):
         return self.get_repo_data(ashare_issuedate_pre,instruments,fields,**kws) 
